==> cloud-4.3.0.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Entity/OpenStackInstance.php <==
<?php

namespace Drupal\openstack\Entity;

use Drupal\aws_cloud\Entity\Ec2\Instance;
use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\aws_cloud\Entity\Ec2\PublicIpEntityLinkHtmlGenerator;

/**
 * Defines the OpenStack Instance entity.
 *
 * @ingroup openstack
 *
 * @ContentEntityType(
 *   id = "openstack_instance",
 *   label = @Translation("Instance"),
 *   id_plural = "openstack_instances",
 *   label_collection = @Translation("Instances"),
 *   label_singular = @Translation("Instance"),
 *   label_plural = @Translation("Instances"),
 *   handlers = {
 *     "view_builder" = "Drupal\aws_cloud\Entity\Ec2\InstanceViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudContentListBuilder",
 *     "views_data" = "Drupal\openstack\Entity\OpenStackInstanceViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "add" = "Drupal\openstack\Form\OpenStackInstanceLaunchForm",
 *       "edit" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "delete" = "Drupal\openstack\Form\OpenStackInstanceDeleteForm",
 *       "start" = "Drupal\openstack\Form\OpenStackInstanceStartForm",
 *       "stop" = "Drupal\openstack\Form\OpenStackInstanceStopForm",
 *       "reboot" = "Drupal\openstack\Form\OpenStackInstanceRebootForm",
 *       "delete-multiple-confirm" = "Drupal\openstack\Form\OpenStackInstanceDeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\aws_cloud\Controller\Ec2\InstanceAccessControlHandler",
 *   },
 *   base_table = "openstack_instance",
 *   admin_permission = "administer openstack instance entities",
 *   fieldable = TRUE,
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "uid",
 *   },
 *   links = {
 *     "canonical" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}",
 *     "edit-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/edit",
 *     "delete-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/terminate",
 *     "collection" = "/clouds/openstack/{cloud_context}/instance",
 *     "start-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/start",
 *     "stop-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/stop",
 *     "reboot-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/reboot",
 *     "delete-multiple-form" = "/clouds/openstack/{cloud_context}/instance/delete_multiple",
 *   },
 *   field_ui_base_route = "openstack_instance.settings"
 * )
 */
class OpenStackInstance extends Instance implements InstanceInterface {

  public const TAG_UID = 'uid';

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['instance_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Instance type'))
      ->setDescription(t("The type of instance determines your instance's CPU capacity, memory, and storage (e.g., m1.small, c1.xlarge)."))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['security_groups'] = BaseFieldDefinition::create('string_long')
      ->setLabel(t('Security groups'))
      ->setDescription(t('The security groups to which the instance belongs. A security group is a collection of firewall rules that restrict the network traffic for the instance. Click View rules to see the rules for the specific group.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_security_group',
          'field_name' => 'name',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['public_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Public IP'))
      ->setDescription(t('The Public IP.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'public_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -8,
      ])
      ->setReadOnly(TRUE);

    $fields['private_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Private IPs'))
      ->setDescription(t('The private IP address of the instance (multiple IP addresses are listed if there is more than one network interface to the instance).'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'private_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -7,
      ])
      ->setReadOnly(TRUE);

    $fields['key_pair_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Key pair name'))
      ->setDescription(t('The name of the key pair that you must use to log in to the instance securely.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_key_pair',
          'field_name' => 'key_pair_name',
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['block_devices'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Volume'))
      ->setDescription(t('The Amazon EBS volumes attached to this instance.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_volume',
          'field_name' => 'volume_id',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    return $fields;
  }

}

==> cloud-5.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Entity/OpenStackInstance.php <==
<?php

namespace Drupal\openstack\Entity;

use Drupal\aws_cloud\Entity\Ec2\Instance;
use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\cloud\Service\Util\EntityLinkWithShortNameHtmlGenerator;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\aws_cloud\Entity\Ec2\PublicIpEntityLinkHtmlGenerator;

/**
 * Defines the OpenStack Instance entity.
 *
 * @ingroup openstack
 *
 * @ContentEntityType(
 *   id = "openstack_instance",
 *   label = @Translation("Instance"),
 *   id_plural = "openstack_instances",
 *   label_collection = @Translation("Instances"),
 *   label_singular = @Translation("Instance"),
 *   label_plural = @Translation("Instances"),
 *   handlers = {
 *     "view_builder" = "Drupal\openstack\Entity\OpenStackInstanceViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudContentListBuilder",
 *     "views_data" = "Drupal\openstack\Entity\OpenStackInstanceViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "add" = "Drupal\openstack\Form\OpenStackInstanceLaunchForm",
 *       "edit" = "Drupal\openstack\Form\OpenStackInstanceEditForm",
 *       "delete" = "Drupal\openstack\Form\OpenStackInstanceDeleteForm",
 *       "start" = "Drupal\openstack\Form\OpenStackInstanceStartForm",
 *       "stop" = "Drupal\openstack\Form\OpenStackInstanceStopForm",
 *       "reboot" = "Drupal\openstack\Form\OpenStackInstanceRebootForm",
 *       "delete-multiple-confirm" = "Drupal\openstack\Form\OpenStackInstanceDeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\aws_cloud\Controller\Ec2\InstanceAccessControlHandler",
 *   },
 *   base_table = "openstack_instance",
 *   admin_permission = "administer openstack instance entities",
 *   fieldable = TRUE,
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "uid",
 *   },
 *   links = {
 *     "canonical" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}",
 *     "edit-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/edit",
 *     "delete-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/terminate",
 *     "collection" = "/clouds/openstack/{cloud_context}/instance",
 *     "start-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/start",
 *     "stop-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/stop",
 *     "reboot-form" = "/clouds/openstack/{cloud_context}/instance/{openstack_instance}/reboot",
 *     "delete-multiple-form" = "/clouds/openstack/{cloud_context}/instance/delete_multiple",
 *   },
 *   field_ui_base_route = "openstack_instance.settings"
 * )
 */
class OpenStackInstance extends Instance implements InstanceInterface {

  /**
   * {@inheritdoc}
   */
  public function setPowerState($power_state): OpenStackInstance {
    return $this->set('power_state', $power_state);
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['instance_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Flavor'))
      ->setDescription(t("The type of instance determines your instance's CPU capacity, memory, and storage (e.g., m1.small, c1.xlarge)."))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['security_groups'] = BaseFieldDefinition::create('string_long')
      ->setLabel(t('Security groups'))
      ->setDescription(t('The security groups to which the instance belongs. A security group is a collection of firewall rules that restrict the network traffic for the instance. Click View rules to see the rules for the specific group.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_security_group',
          'field_name' => 'name',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['public_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Public IP'))
      ->setDescription(t('The Public IP.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'public_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -8,
      ])
      ->setReadOnly(TRUE);

    $fields['private_ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Private IPs'))
      ->setDescription(t('The private IP address of the instance (multiple IP addresses are listed if there is more than one network interface to the instance).'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_floating_ip',
          'field_name' => 'private_ip',
          'html_generator_class' => PublicIpEntityLinkHtmlGenerator::class,
        ],
        'weight' => -7,
      ])
      ->setReadOnly(TRUE);

    $fields['key_pair_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Key pair name'))
      ->setDescription(t('The name of the key pair that you must use to log in to the instance securely.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_key_pair',
          'field_name' => 'key_pair_name',
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    $fields['block_devices'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Volume'))
      ->setDescription(t('The Amazon EBS volumes attached to this instance.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_volume',
          'field_name' => 'volume_id',
          'comma_separated' => TRUE,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    // Insert power_state after instance_state.
    $pos = array_search('instance_state', array_keys($fields));
    $field_power_state = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Power state'))
      ->setDescription(t('The power state of the instance.'))
      ->setSetting('allowed_values', [
        '0' => 'nostate',
        '1' => 'running',
        '3' => 'paused',
        '4' => 'shutdown',
        '6' => 'crashed',
        '7' => 'suspended',
      ])
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);
    $fields = array_merge(
      array_slice($fields, 0, $pos + 1),
      ['power_state' => $field_power_state],
      array_slice($fields, $pos + 1)
    );

    $fields['image_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OpenStack Image Name'))
      ->setDescription(t('The Name of the OpenStack image with which the instance was launched.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'entity_link',
        'settings' => [
          'target_type' => 'openstack_image',
          'field_name' => 'image_id',
          'comma_separated' => TRUE,
          'html_generator_class' => EntityLinkWithShortNameHtmlGenerator::class,
        ],
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    return $fields;
  }

}
